==> zio-aws-lakeformation_2.13-5.17.116.1-sources.jar: zio/aws/lakeformation/model/CreateLfTagRequest.scala <==
package zio.aws.lakeformation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.lakeformation.model.primitives.{
  LFTagValue,
  LFTagKey,
  CatalogIdString
}
import scala.jdk.CollectionConverters._
final case class CreateLfTagRequest(
    catalogId: Option[CatalogIdString] = None,
    tagKey: LFTagKey,
    tagValues: Iterable[LFTagValue]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lakeformation.model.CreateLfTagRequest = {
    import CreateLfTagRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lakeformation.model.CreateLfTagRequest
      .builder()
      .optionallyWith(
        catalogId.map(value => CatalogIdString.unwrap(value): java.lang.String)
      )(_.catalogId)
      .tagKey(LFTagKey.unwrap(tagKey): java.lang.String)
      .tagValues(tagValues.map { item =>
        LFTagValue.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.lakeformation.model.CreateLfTagRequest.ReadOnly =
    zio.aws.lakeformation.model.CreateLfTagRequest.wrap(buildAwsValue())
}
object CreateLfTagRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lakeformation.model.CreateLfTagRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lakeformation.model.CreateLfTagRequest =
      zio.aws.lakeformation.model
        .CreateLfTagRequest(catalogId.map(value => value), tagKey, tagValues)
    def catalogId: Option[CatalogIdString]
    def tagKey: LFTagKey
    def tagValues: List[LFTagValue]
    def getCatalogId: ZIO[Any, AwsError, CatalogIdString] =
      AwsError.unwrapOptionField("catalogId", catalogId)
    def getTagKey: ZIO[Any, Nothing, LFTagKey] = ZIO.succeed(tagKey)
    def getTagValues: ZIO[Any, Nothing, List[LFTagValue]] =
      ZIO.succeed(tagValues)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lakeformation.model.CreateLfTagRequest
  ) extends zio.aws.lakeformation.model.CreateLfTagRequest.ReadOnly {
    override val catalogId: Option[CatalogIdString] = scala
      .Option(impl.catalogId())
      .map(value =>
        zio.aws.lakeformation.model.primitives.CatalogIdString(value)
      )
    override val tagKey: LFTagKey =
      zio.aws.lakeformation.model.primitives.LFTagKey(impl.tagKey())
    override val tagValues: List[LFTagValue] = impl
      .tagValues()
      .asScala
      .map { item =>
        zio.aws.lakeformation.model.primitives.LFTagValue(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.lakeformation.model.CreateLfTagRequest
  ): zio.aws.lakeformation.model.CreateLfTagRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lakeformation_2.13-6.20.78.2-sources.jar: zio/aws/lakeformation/model/CreateLfTagRequest.scala <==
package zio.aws.lakeformation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.lakeformation.model.primitives.{
  LFTagValue,
  LFTagKey,
  CatalogIdString
}
import scala.jdk.CollectionConverters._
final case class CreateLfTagRequest(
    catalogId: Optional[CatalogIdString] = Optional.Absent,
    tagKey: LFTagKey,
    tagValues: Iterable[LFTagValue]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lakeformation.model.CreateLfTagRequest = {
    import CreateLfTagRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lakeformation.model.CreateLfTagRequest
      .builder()
      .optionallyWith(
        catalogId.map(value => CatalogIdString.unwrap(value): java.lang.String)
      )(_.catalogId)
      .tagKey(LFTagKey.unwrap(tagKey): java.lang.String)
      .tagValues(tagValues.map { item =>
        LFTagValue.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.lakeformation.model.CreateLfTagRequest.ReadOnly =
    zio.aws.lakeformation.model.CreateLfTagRequest.wrap(buildAwsValue())
}
object CreateLfTagRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lakeformation.model.CreateLfTagRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lakeformation.model.CreateLfTagRequest =
      zio.aws.lakeformation.model
        .CreateLfTagRequest(catalogId.map(value => value), tagKey, tagValues)
    def catalogId: Optional[CatalogIdString]
    def tagKey: LFTagKey
    def tagValues: List[LFTagValue]
    def getCatalogId: ZIO[Any, AwsError, CatalogIdString] =
      AwsError.unwrapOptionField("catalogId", catalogId)
    def getTagKey: ZIO[Any, Nothing, LFTagKey] = ZIO.succeed(tagKey)
    def getTagValues: ZIO[Any, Nothing, List[LFTagValue]] =
      ZIO.succeed(tagValues)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lakeformation.model.CreateLfTagRequest
  ) extends zio.aws.lakeformation.model.CreateLfTagRequest.ReadOnly {
    override val catalogId: Optional[CatalogIdString] = zio.aws.core.internal
      .optionalFromNullable(impl.catalogId())
      .map(value =>
        zio.aws.lakeformation.model.primitives.CatalogIdString(value)
      )
    override val tagKey: LFTagKey =
      zio.aws.lakeformation.model.primitives.LFTagKey(impl.tagKey())
    override val tagValues: List[LFTagValue] = impl
      .tagValues()
      .asScala
      .map { item =>
        zio.aws.lakeformation.model.primitives.LFTagValue(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.lakeformation.model.CreateLfTagRequest
  ): zio.aws.lakeformation.model.CreateLfTagRequest.ReadOnly = new Wrapper(impl)
}
